CapabilityManifest

Struct CapabilityManifest 

pub struct CapabilityManifest {
Show 22 fields pub id: String, pub contract_version: String, pub content_digest: String, pub kind: CapabilityKind, pub input_schema: Value, pub output_schema: Value, pub effect: Effect, pub deterministic: bool, pub idempotency_mode: IdempotencyMode, pub retry: RetryPolicy, pub permissions: BTreeSet<String>, pub required_guards: BTreeSet<GuardKind>, pub taint_rules: Value, pub resource_cost: Value, pub supports_simulation: bool, pub supports_replay: bool, pub supports_paper: bool, pub supports_live: bool, pub clock_requirements: Value, pub data_requirements: Value, pub supports_reconciliation: bool, pub lifecycle: CapabilityLifecycle,
}
Immutable contract of a trigger, expression, guard, action or sink.

Fields

id: String

Stable identifier of this record.

contract_version: String

Contract version of the capability.

content_digest: String

Content hash that makes the referenced artifact immutable.

kind: CapabilityKind

Discriminator naming the variant of this record.

input_schema: Value

JSON Schema for provider input.

output_schema: Value

JSON Schema for provider output.

effect: Effect

Side-effect class of the action.

deterministic: bool

Whether equal inputs always produce equal outputs.

idempotency_mode: IdempotencyMode

Retry safety class.

retry: RetryPolicy

Retry policy.

permissions: BTreeSet<String>

Permissions granted or required.

required_guards: BTreeSet<GuardKind>

Guards that must dominate the action.

taint_rules: Value

Which inputs may be LLM-tainted.

resource_cost: Value

Declared cost for budgeting.

supports_simulation: bool

Usable in simulation.

supports_replay: bool

Usable in backtest replay.

supports_paper: bool

Usable in paper mode.

supports_live: bool

Usable live.

clock_requirements: Value

Clock guarantees the provider needs.

data_requirements: Value

Data freshness the provider needs.

supports_reconciliation: bool

Whether the provider can observe a dispatched action’s outcome.

lifecycle: CapabilityLifecycle

Deployment state.

Implementations

Source

impl CapabilityManifest

pub fn action( id: impl Into<String>, contract_version: impl Into<String>, content_digest: impl Into<String>, effect: Effect, idempotency_mode: IdempotencyMode, supports_reconciliation: bool, ) -> Self

Manifest for an action capability with conservative defaults (one attempt, 30 s timeout).

pub fn validate(&self) -> Result<(), ContractError>

Check this contract’s invariants; returns the first violation.

pub fn can_start_new_work(&self) -> bool

Whether new intents may pin this provider (installed or active).