Module result

Module result 

What a step node returns. Port of platform/types.py Pass / Drop / FanOut.

Structs

PreparedAction
Product-owned action data emitted by an execute.* step. The durable driver adds tenant, run, lease, control and exact capability pins.

Enums

PreparedActionError
Invalid product action prepared for durable dispatch.
StepResult
The outcome of running one event through one crate::node::StepNode.